<?php

/* Class Configs 1.1
 * Retrieve configuration parameters from the core.ini configuration file.
 *
 * Copyright 2012 Solues Office (www.solucoesoffice.com.br)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

class Configs{
    // Holds an instance
    private static $instance;
    private $data;
    
    // Prevents the direct object creation of the class.
    private function __construct() {
    	$this->load();
    }

    // Singleton method used for instanciation 
    public static function singleton(){
        if (!isset(self::$instance)) {
            $c = __CLASS__;
            self::$instance = new $c;
        }
        return self::$instance;
    }
    
    // Prevents the user from clonning the instance.
    public function __clone(){
        trigger_error('Clone is not allowed.', E_USER_ERROR);
    }
    
    function __set($var, $value){
    	$this->data[$var] = $value;
    }
    
    function __get($var){
    	return $this->data[$var];
    }
    
    //Loads values from the core.ini file
    function load(){
    	$core = parse_ini_file(CONFIGS . DS . 'core.ini', true);
		foreach($core as $key => $value){
			$this->data[$key] = $value;
		}
    }
    
    //Returns the DATA array
    function getArray(){
    	return $this->data;
    }
}